@@ -406,9 +406,6 @@ public class Jsoner{
 				case '\t':
 					builder.append("\\t");
 					break;
-				case '/':
-					builder.append("\\/");
-					break;
 				default:
 					/* The many characters that get replaced are benign to software but could be mistaken by people
 					 * reading it for a JSON relevant character. */
@@ -483,7 +480,7 @@ public class Jsoner{
 	 *        Jsoner#serialize(Object).
 	 * @param writable represents where the pretty printed JSON should be written to.
 	 * @param indentation representing the indentation used to format the JSON string. NOT validated as a proper
-	 *        indentation. It is recommended to use tabs ("\t"), but 3, 4, or 8 spaces are common alternatives.
+	 *        indentation. It is recommended to use tabs ("\t"), but 3 or 4 spaces are common alternatives.
 	 * @param newline representing the newline used to format the JSON string. NOT validated as a proper newline. It is
 	 *        recommended to use "\n", but "\r" or "/r/n" are common alternatives.
 	 * @throws IOException if the provided writer encounters an IO issue.
@@ -499,6 +496,7 @@ public class Jsoner{
 			switch(lexed.getType()){
 				case COLON:
 					writable.append(lexed.getValue().toString());
+					writable.append(' ');
 					break;
 				case COMMA:
 					writable.append(lexed.getValue().toString());
@@ -562,39 +560,6 @@ public class Jsoner{
 		return writer.toString();
 	}
 
-	/** A convenience method to pretty print a String with the provided spaces count and "\n" for newlines.
-	 * @param printable representing a JSON formatted string with out extraneous characters, like one returned from
-	 *        Jsoner#serialize(Object).
-	 * @param spaces representing the amount of spaces to use for indentation. Must be between 2 and 10.
-	 * @return printable except it will have '\n' then space characters inserted after '[', '{', ',' and before ']' '}'
-	 *         tokens in the JSON. It will return null if printable isn't a JSON string.
-	 * @throws IllegalArgumentException if spaces isn't between [2..10].
-	 * @see Jsoner#prettyPrint(String)
-	 * @since 2.2.0 to allow pretty printing with spaces instead of tabs.
-	 * @deprecated 3.1.0 in favor of Jsoner#prettyPrint(Reader, Writer, String, String) due to arbitrary limitations
-	 *             enforced by this implementation. */
-	@Deprecated
-	public static String prettyPrint(final String printable, final int spaces){
-		if((spaces > 10) || (spaces < 2)){
-			throw new IllegalArgumentException("Indentation with spaces must be between 2 and 10.");
-		}
-		final StringBuilder indentation = new StringBuilder("");
-		final StringWriter writer = new StringWriter();
-		for(int i = 0; i < spaces; i++){
-			indentation.append(" ");
-		}
-		try{
-			Jsoner.prettyPrint(new StringReader(printable), writer, indentation.toString(), "\n");
-		}catch(final IOException caught){
-			/* See java.io.StringReader.
-			 * See java.io.StringWriter. */
-		}catch(final JsonException caught){
-			/* Would have been caused by a an IO exception while lexing, but the StringReader does not throw them. See
-			 * java.io.StringReader. */
-		}
-		return writer.toString();
-	}
-
 	/** A convenience method that assumes a StringWriter.
 	 * @param jsonSerializable represents the object that should be serialized as a string in JSON format.
 	 * @return a string, in JSON format, that represents the object provided.
@@ -634,7 +599,7 @@ public class Jsoner{
 			writableDestination.write("null");
 		}else if(((jsonSerializable instanceof Jsonable) && flags.contains(SerializationOptions.ALLOW_JSONABLES))){
 			/* Writes the writable as defined by the writable. */
-			writableDestination.write(((Jsonable)jsonSerializable).toJson());
+			((Jsonable)jsonSerializable).toJson(writableDestination);
 		}else if(jsonSerializable instanceof String){
 			/* Make sure the string is properly escaped. */
 			writableDestination.write('"');
